"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UncodedError = void 0;
const core_1 = require("@creatio-tech/core");
const class_validator_1 = require("class-validator");
const error_code_1 = require("../../enum/error.code");
const validation_error_1 = require("./validation.error");
class UncodedError extends core_1.BaseError {
    static async validate(instance) {
        const validationError = await (0, class_validator_1.validate)(instance, {
            validationError: { target: false, value: false },
        });
        if (validationError.length > 0) {
            return new validation_error_1.ValidationError(core_1.ErrorStatus.UNPROCESSABLE_ENTITY, 'validation_errors', error_code_1.ErrorCode.UNPROCESSABLE_ENTITY_BASE, UncodedError.TypeName, core_1.ValidatorHelper.getValidation(validationError));
        }
        return undefined;
    }
    async validate() {
        return await UncodedError.validate(this);
    }
    static plainToClass(source) {
        const instance = new UncodedError();
        if (source !== undefined) {
            instance.status = Object.values(core_1.ErrorStatus).includes(source.status) === true
                ? core_1.ErrorStatus[source.status]
                : core_1.ErrorStatus.NONE;
            instance.message = core_1.StringHelper.transformString(source.message);
        }
        return instance;
    }
    static classToClass(source) {
        const instance = new UncodedError();
        if (source !== undefined) {
            instance.status = source.status;
            instance.message = core_1.StringHelper.transformString(source.message);
        }
        return instance;
    }
    constructor(status, message) {
        super();
        this.status = status !== null && status !== void 0 ? status : core_1.ErrorStatus.NONE;
        this.message = message !== null && message !== void 0 ? message : '';
    }
}
exports.UncodedError = UncodedError;
UncodedError.TypeName = 'UncodedError';
//# sourceMappingURL=uncoded.error.js.map