"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomErrorHandler = void 0;
const routing_controllers_1 = require("routing-controllers");
const logging_1 = require("@creatio-tech/logging");
const core_1 = require("@creatio-tech/core");
const error_response_1 = require("../entity/error.response");
const internal_error_1 = require("../entity/error/internal.error");
const error_code_1 = require("../enum/error.code");
class CustomErrorHandler {
    handleError(err, req, res, next) {
        (0, logging_1.Logger)().error(`Handle Error > Error: ${err} | Next: ${next !== undefined ? true : false}`);
        if (err instanceof routing_controllers_1.HttpError) {
            if (err.httpCode === core_1.ErrorStatus.UNAUTHORIZED || err.httpCode === core_1.ErrorStatus.FORBIDDEN ||
                err.httpCode === core_1.ErrorStatus.NOT_FOUND || err.httpCode === core_1.ErrorStatus.EXPECTATION_FAILED) {
                (0, logging_1.Logger)().warn(core_1.ErrorHelper.toErrorString(err));
            }
            else {
                (0, logging_1.Logger)().error(core_1.ErrorHelper.toErrorString(err));
            }
        }
        else {
            (0, logging_1.Logger)().error(core_1.ErrorHelper.toErrorString(err));
        }
        if (err instanceof routing_controllers_1.HttpError) {
            res.status(err.httpCode);
            res.json(err);
        }
        else if (err.httpCode !== undefined && err.message !== undefined) {
            res.status(err.httpCode);
            res.json({
                message: err.message,
                status: err.httpCode,
            });
        }
        else {
            const error = new internal_error_1.InternalError(core_1.ErrorStatus.INTERNAL_SERVER_ERROR, 'Oops! Something went wrong in the service', error_code_1.ErrorCode.INTERNAL_SERVER_ERROR_BASE);
            const errorResponse = new error_response_1.ErrorResponse(error);
            res.status(errorResponse.httpCode);
            res.json(errorResponse);
        }
    }
}
exports.CustomErrorHandler = CustomErrorHandler;
//# sourceMappingURL=custom.error.handler.js.map